@@ -145,7 +145,9 @@ class TrafficItem(CustomField):
                     'TrafficItemType': 'l2L3',
                     'TrafficType': self._get_traffic_type(flow)
                 }
-                ixn_traffic_item.find(Name=flow.name)
+                ixn_traffic_item.find(Name=flow.name, TrafficType=args['TrafficType'])
+                if len(ixn_traffic_item) == 1:
+                    ixn_traffic_item.remove()
                 if len(ixn_traffic_item) == 0:
                     ixn_traffic_item.add(**args)
                 else:
@@ -157,7 +159,21 @@ class TrafficItem(CustomField):
                 self._configure_size(ixn_stream, flow.size)
                 self._configure_rate(ixn_stream, flow.rate)
                 self._configure_tx_control(ixn_stream, flow.duration)
+                self._configure_options(flow)
+            self._api._traffic_item.find()
+            if len(self._api._traffic_item) > 0:
+                self._api._traffic_item.Generate()
     
+    def _configure_options(self, flow):
+        enable_min_frame_size = False
+        if (len(flow.packet) == 1 and 
+            flow.packet[0].choice == 'pfcpause' and 
+            flow.size.choice == 'fixed' and 
+            flow.size.fixed <= 64):
+            enable_min_frame_size = True
+        if self._api._traffic.EnableMinFrameSize != enable_min_frame_size:
+            self._api._traffic.EnableMinFrameSize = enable_min_frame_size
+
     def _get_traffic_type(self, flow):
         if flow.tx_rx is None:
             raise ValueError('%s Flow.tx_rx property cannot be None' % flow.name)
@@ -227,7 +243,6 @@ class TrafficItem(CustomField):
                 else:
                     stack = ixn_stack[i]
             self._configure_field(stack.Field, header)
-        self._api._traffic_item.Generate()
         for stack in stacks_to_remove:
             stack.Remove()
     
@@ -340,31 +355,28 @@ class TrafficItem(CustomField):
         if duration is None:
             return
         ixn_tx_control = ixn_stream.TransmissionControl
-        if duration.choice == 'fixed':
-            if duration.fixed.delay_unit not in ['bytes', 'nanoseconds', None]:
-                duration.fixed.delay_unit = 'bytes'
-            if duration.fixed.packets <= 0:
-                ixn_tx_control.update(Type='continuous',
-                    MinGapBytes=duration.fixed.gap,
-                    StartDelay=duration.fixed.delay,
-                    StartDelayUnits=duration.fixed.delay_unit)
-            else:
-                ixn_tx_control.update(Type='fixedFrameCount',
-                    FrameCount=duration.fixed.packets,
-                    MinGapBytes=duration.fixed.gap,
-                    StartDelay=duration.fixed.delay,
-                    StartDelayUnits=duration.fixed.delay_unit)
+        if duration.choice == 'continuous':
+            ixn_tx_control.update(Type='continuous',
+                MinGapBytes=duration.continuous.gap,
+                StartDelay=duration.continuous.delay,
+                StartDelayUnits=duration.continuous.delay_unit)
+        elif duration.choice == 'packets':
+            ixn_tx_control.update(Type='fixedFrameCount',
+                FrameCount=duration.packets.packets,
+                MinGapBytes=duration.packets.gap,
+                StartDelay=duration.packets.delay,
+                StartDelayUnits=duration.packets.delay_unit)
+        elif duration.choice == 'seconds':
+            ixn_tx_control.update(Type='fixedDuration',
+                Duration=duration.seconds.seconds,
+                MinGapBytes=duration.seconds.gap,
+                StartDelay=duration.seconds.delay,
+                StartDelayUnits=duration.seconds.delay_unit)
         elif duration.choice == 'burst':
-            enable_gap = False
-            if (duration.burst.inter_burst_gap is not None or
-                duration.burst.inter_burst_gap_unit is not None):
-                enable_gap = True
-            if duration.burst.inter_burst_gap_unit not in ['bytes', 'nanoseconds', None]:
-                duration.burst.inter_burst_gap_unit = 'bytes'
             ixn_tx_control.update(Type='custom',
                 BurstPacketCount=duration.burst.packets,
                 MinGapBytes=duration.burst.gap,
-                EnableInterBurstGap=enable_gap,
+                EnableInterBurstGap=True if duration.burst.gap > 0 else False,
                 InterBurstGap=duration.burst.inter_burst_gap,
                 InterBurstGapUnits=duration.burst.inter_burst_gap_unit)
 
@@ -394,12 +406,43 @@ class TrafficItem(CustomField):
         elif request.state == 'resume':
             self._api._traffic_item.PauseStatelessTrafficBlocking(False)
 
-    def _set_result_value(self, row, column_name, column_value):
-        row[TrafficItem._RESULT_COLUMNS.index(column_name)] = column_value
+    def _set_result_value(self, row, column_name, column_value, column_type = str):
+        if len(self._column_names) > 0 and column_name not in self._column_names:
+            return
+        try:
+            row[column_name] = column_type(column_value)
+        except:
+            if column_type.__name__ in ['float', 'int']:
+                row[column_name] = 0
+            else:
+                row[column_type] = column_value
 
+    def _get_state(self, state):
+        """IxNetwork traffic item states
+            error, locked, started, 
+            startedWaitingForStats, startedWaitingForStreams, stopped, 
+            stoppedWaitingForStats, txStopWatchExpected, unapplied
+        """
+        started_states =  [
+            'txStopWatchExpected', 
+            'locked', 
+            'started', 
+            'startedWaitingForStats', 
+            'startedWaitingForStreams', 
+            'stoppedWaitingForStats'
+        ]
+        if state in started_states:
+            return 'started'
+        else:
+            return 'stopped'
+            
     def results(self, request):
         """Return flow results
         """
+        if request.column_names is None:
+            self._column_names = []
+        else:
+            self._column_names = request.column_names
         filter = {
             'property': 'name',
             'regex': '.*'
@@ -408,9 +451,9 @@ class TrafficItem(CustomField):
             filter['regex'] = '^(%s)$' % '|'.join(request.flow_names)
         flow_rows = {}
         for traffic_item in self._api.select_traffic_items(traffic_item_filters=[filter]).values():
-            flow_row = [0 for i in range(len(TrafficItem._RESULT_COLUMNS))]
+            flow_row = {}
             self._set_result_value(flow_row, 'name', traffic_item['name'])
-            self._set_result_value(flow_row, 'state', traffic_item['state'])
+            self._set_result_value(flow_row, 'transmit', self._get_state(traffic_item['state']))
             self._set_result_value(flow_row, 'port_tx', traffic_item['highLevelStream'][0]['txPortName'])
             self._set_result_value(flow_row, 'port_rx', ' '.join(traffic_item['highLevelStream'][0]['rxPortNames']))
             flow_rows[traffic_item['name']] = flow_row
@@ -419,17 +462,14 @@ class TrafficItem(CustomField):
             table.AddRowFilter('Traffic Item', StatViewAssistant.REGEX, filter['regex'])
             for row in table.Rows:
                 flow_row = flow_rows[row['Traffic Item']]
-                self._set_result_value(flow_row, 'frames_tx', row['Tx Frames'])
-                self._set_result_value(flow_row, 'frames_rx', row['Rx Frames'])
-                self._set_result_value(flow_row, 'frames_tx_rate', row['Tx Frame Rate'])
-                self._set_result_value(flow_row, 'frames_rx_rate', row['Rx Frame Rate'])
-                self._set_result_value(flow_row, 'bytes_tx_rate', row['Tx Rate (Bps)'])
-                self._set_result_value(flow_row, 'bytes_rx_rate', row['Rx Rate (Bps)'])
-                self._set_result_value(flow_row, 'loss', row['Loss %'])
+                self._set_result_value(flow_row, 'frames_tx', row['Tx Frames'], int)
+                self._set_result_value(flow_row, 'frames_rx', row['Rx Frames'], int)
+                self._set_result_value(flow_row, 'bytes_rx', row['Rx Bytes'], int)
+                self._set_result_value(flow_row, 'frames_tx_rate', row['Tx Frame Rate'], float)
+                self._set_result_value(flow_row, 'frames_rx_rate', row['Rx Frame Rate'], float)
+                self._set_result_value(flow_row, 'bytes_tx_rate', row['Tx Rate (Bps)'], float)
+                self._set_result_value(flow_row, 'bytes_rx_rate', row['Rx Rate (Bps)'], float)
+                self._set_result_value(flow_row, 'loss', row['Loss %'], float)
         except Exception as e:
             self._api.add_error(e)
-        results = {
-            'columns': TrafficItem._RESULT_COLUMNS,
-            'rows': flow_rows.values()
-        }
-        return results
+        return flow_rows.values()
